summary refs log tree commit diff stats
path: root/registry/types.go
diff options
context:
space:
mode:
authorBen Morrison <ben@gbmor.dev>2019-05-14 03:08:07 -0400
committerBen Morrison <ben@gbmor.dev>2019-05-14 03:08:07 -0400
commit2492014051e5cd4c37287a09639d18f85e1349dc (patch)
treefa3af5377e10f6f6748390d1969b5879bc21593a /registry/types.go
parenta8ba50b53f45e06af03f5ef98e759539394a3c0c (diff)
downloadgetwtxt-2492014051e5cd4c37287a09639d18f85e1349dc.tar.gz
moved query functions to own file, made SortByTime query-agnostic
Diffstat (limited to 'registry/types.go')
-rw-r--r--registry/types.go10
1 files changed, 5 insertions, 5 deletions
diff --git a/registry/types.go b/registry/types.go
index d3e421a..43b323f 100644
--- a/registry/types.go
+++ b/registry/types.go
@@ -19,16 +19,16 @@ type Data struct {
 	nick    string
 	date    time.Time
 	apidate []byte
-	status  StatusMap
+	status  TimeMap
 }
 
-// StatusMap holds the statuses posted by a given user. A standard
-// time.Time value is used as the key, with the status as a string.
-type StatusMap map[time.Time]string
+// TimeMap holds extracted and processed user data as a
+// string. A standard time.Time value is used as the key.
+type TimeMap map[time.Time]string
 
 // StatusMapSlice is a slice of StatusMaps. Useful for sorting the
 // output of queries.
-type StatusMapSlice []StatusMap
+type TimeMapSlice []TimeMap
 
 // Mutex to control access to the User Index.
 var imutex = sync.RWMutex{}